rtc: Refactor to allow avg_frame_low_motion when aq-mode=0

avg_frame_low_motion, which is used in various places in rtc
code patch, was only updated when aq_mode=3, even though it can
be used when aq_mode=0. This change makes the update/compuation
of avg_frame_low_motion for rtc encoding, regardless of aq_mode.

No change in stats when aq_mode=3.

Change-Id: I67adc5108b0875f3f699abafd9948b28d118d14e
diff --git a/av1/encoder/ethread.c b/av1/encoder/ethread.c
index 45f7e17..bc34d36 100644
--- a/av1/encoder/ethread.c
+++ b/av1/encoder/ethread.c
@@ -1195,11 +1195,9 @@
     EncWorkerData *const thread_data = (EncWorkerData *)worker->data1;
     cpi->intrabc_used |= thread_data->td->intrabc_used;
     cpi->deltaq_used |= thread_data->td->deltaq_used;
-    // Accumulate cyclic refresh params.
-    if (cpi->oxcf.q_cfg.aq_mode == CYCLIC_REFRESH_AQ &&
-        !frame_is_intra_only(&cpi->common))
-      av1_accumulate_cyclic_refresh_counters(cpi->cyclic_refresh,
-                                             &thread_data->td->mb);
+    // Accumulate rtc counters.
+    if (!frame_is_intra_only(&cpi->common))
+      av1_accumulate_rtc_counters(cpi, &thread_data->td->mb);
     if (thread_data->td != &cpi->td) {
       // Keep these conditional expressions in sync with the corresponding ones
       // in prepare_enc_workers().
@@ -1294,8 +1292,8 @@
     }
     av1_alloc_mb_data(cpi, &thread_data->td->mb);
 
-    // Reset cyclic refresh counters.
-    av1_init_cyclic_refresh_counters(&thread_data->td->mb);
+    // Reset rtc counters.
+    av1_init_rtc_counters(&thread_data->td->mb);
 
     if (thread_data->td->counts != &cpi->counts) {
       memcpy(thread_data->td->counts, &cpi->counts, sizeof(cpi->counts));